/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis;

import java.util.*;
import java.io.*;
import java.util.regex.*;

import org.biojava.bio.*;
import org.biojava.bio.seq.*;
import org.biojava.bio.symbol.*;
import org.biojava.bio.seq.impl.*;
import org.biojava.bio.seq.io.*;

import uk.ac.sanger.psu.gfmerge.datacomp.*;
import uk.ac.sanger.psu.gfmerge.util.io.*;
import uk.ac.sanger.psu.gfmerge.util.getopt.*;
import uk.ac.sanger.psu.gfmerge.util.biotools.*;
import uk.ac.sanger.psu.gfmerge.util.algotools.*;
import uk.ac.sanger.psu.gfmerge.util.debug.*;
import uk.ac.sanger.psu.gfmerge.analysis.*;
import uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis.*;
import uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis.tools.*;

/** Abstract class which contains partial implementation of derived overlap analysis classes
 * 
 * @author Sebastian R. Spiegler
 * @version 1.0
 */
public abstract class FeatureOverlapAnalysis extends FeatureAnalysis
{

  ///////////////////////////////////////
  // attributes
  /** ArrayList of genemodel regions
   */
  private ArrayList arrListOfGMRegions;
  /** ArrayList of SimFeature regions
   */
  private ArrayList arrListOfFeatRegions;
  /** SimpleArg object which contains all command line arguments
   */
  private SimpleArg allArguments;

  ///////////////////////////////////////
  // constructor
  /** constructor of abstract FeatureOverlapAnalysis class, contains partial implementation of constructors of derived overlap analysis classes
   * 
   * @param _arrListOfGMRegions ArrayList of genemodel regions
   * @param _arrListOfFeatRegions ArrayList of SimFeature regions
   * @param _allArguments SimpleArg object which contains all command 
   *     line arguments
   */
  public FeatureOverlapAnalysis(ArrayList _arrListOfGMRegions,
                                ArrayList _arrListOfFeatRegions,
                                SimpleArg _allArguments)
  {
    super(_arrListOfGMRegions,_arrListOfFeatRegions, _allArguments);
  }
}
