/*
 * This file is part of GFMerge. Copyright (c) 2003 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis.tools;

import java.util.*;

import org.biojava.bio.symbol.*;

import uk.ac.sanger.psu.gfmerge.datacomp.*;
import uk.ac.sanger.psu.gfmerge.util.algotools.*;
import uk.ac.sanger.psu.gfmerge.util.debug.*;

/** class which contains all computing tools for AvgCondProbAnalysis
 * 
 * @author Sebastian R. Spiegler
 * @version 1.0
 */
public class AvgCondProbAnalysisTools /*extends BasicFeatureAnalysisTools*/
{

  /** method which returns a hash of genemodels pointing to their score
   * 
   * @param debug debuggin mode
   * @param _arrListOfGMRegions ArrayList of genemodel regions
   * @return HashMap of genemodels pointing to their score
   */
  public static HashMap getAcpScoredGmHash(int debug,
                                           ArrayList _arrListOfGMRegions)
  {
    HashMap acpScoredGmHash = new HashMap();

    for(Iterator itReg = _arrListOfGMRegions.iterator(); itReg.hasNext();)
    {
      GFMergeRegion region = (GFMergeRegion) itReg.next();
      ArrayList gmArr      = (ArrayList) region.getLocateable();

      for (Iterator itGm = gmArr.iterator(); itGm.hasNext(); )
      {
        GeneModel gm = (GeneModel) itGm.next();
        double acp = gm.getPrediction().getGenePredicter().getAcp();
        acpScoredGmHash.put(gm, new Double(acp));
      }
    }
    return acpScoredGmHash;
  }
}
