/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.datacomp;

/** This typesafe enumeration construct replaces primitive constants
 * with a set of static final object references encapsulated in this class
 * that restricts further instantiation.
 *
 * @author Sebastian R. Spiegler
 * @see uk.ac.sanger.psu.gfmerge.datacomp.Exon
 * @see uk.ac.sanger.psu.gfmerge.datacomp.FeatureComponentAble
 * @version 1.0
 */

public final class ExonType {

  ///////////////////////////////////////
  // attributes

  private final String name;

  ///////////////////////////////////////
  // operations
  /** @param name
   */
  private ExonType(String name) {
    this.name = name;
  }

  public String toString() {
    return name;
  }

  public static final ExonType
      TYPE_5_END = new ExonType("TYPE_5END"),
      TYPE_3_END = new ExonType("TYPE_3END"),
      TYPE_INTERNAL = new ExonType("TYPE_INTERNAL"),
      TYPE_SINGLE_EXON_GENE = new ExonType(" TYPE_SINGLE_EXON_GENE");
}