/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.datacomp;

import java.util.*;
import org.biojava.bio.symbol.*;

import uk.ac.sanger.psu.gfmerge.util.biotools.*;
import uk.ac.sanger.psu.gfmerge.util.algotools.*;

/** class which represents a cluster of overlapping features on a sequence.
 *
 * @author Sebastian R. Spiegler
 * @version 1.0
 */
public class GFMergeRegion {//implements LocateAble{

  ///////////////////////////////////////
  // attributes

    /** cluster location
     */
    private Location location;
    /** ArrayList of features objects (implementing LocateAble interface)
     */
    private ArrayList locatable;            // array list of LocateAble objects

   ///////////////////////////////////////
   // constructor

   /** constructor of GFMergeRegion objects
    *
    * @param _location location of the cluster
    * @param _locateable overlapping features within the cluster
    */
   public  GFMergeRegion(Location _location, ArrayList _locateable)
   {
     setLocation(_location);
     setLocateable(_locateable);
   } // end Region


  ///////////////////////////////////////
  // operations

    /** accessor method which returns location of the cluster
     *
     * @return location of the cluster
     */
    public Location getLocation()
    {
        return location;
    } // end getLocation

    /** accessor method which sets location of the cluster
     *
     * @param _location location of the cluster
     */
    private void setLocation(Location _location)
    {
        location = _location;
    } // end setLocation

    /** accessor method which returns ArrayList of overlapping features in cluster
     *
     * @return ArrayList of overlapping features in cluster
     */
    public ArrayList getLocateable()
    {
        return locatable;
    } // end getGeneModels

    /** accessor method which sets ArrayList of overlapping features in cluster
     *
     * @param _locateable ArrayList of overlapping features in cluster
     */
    private void setLocateable(ArrayList _locateable)
    {
        locatable = _locateable;
    } // end setGeneModels

} // end Region
