/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.datacomp;

import java.util.*;
import org.biojava.bio.seq.*;
import org.biojava.bio.symbol.*;
import uk.ac.sanger.psu.gfmerge.util.biotools.*;
import uk.ac.sanger.psu.gfmerge.util.algotools.*;

/** class is representing a genemodel.
 * GeneModel wraps the BioJava feature class.
 * <p>
 * For example:
 * <pre>
 * GeneModel gm = new GeneModel(prediction, feature);
 * </pre>
 * 
 * @author Sebastian R. Spiegler
 * @version 1.0
 */

public class GeneModel extends GFMergeFeature implements GeneModelAble {

  ///////////////////////////////////////
  // attributes

    /** reference to prediction object.
     */
    private Prediction prediction;

  ///////////////////////////////////////
  // constructor

    /** constructor for GeneModel objects.
     * 
     * @param prediction reference to prediction object
     * @param feature reference to BioJava feature object
     */
    public  GeneModel(Prediction prediction, StrandedFeature feature)
    {
      super(feature);
      setPrediction(prediction);
    } // end GeneModel

    ///////////////////////////////////////
    // operations

    /** accessor method which returns reference to prediction object.
     * 
     * @return reference to prediction
     */
    public Prediction getPrediction()
    {
      return prediction;
    }


    /** accessor method which sets reference to prediction.
     * 
     * @param _prediction reference to prediction object
     */
    private void setPrediction(Prediction _prediction)  //done
    {
      prediction = _prediction;
    }

} // end GeneModel
