/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.datacomp;

import java.util.*;

/** class which represents a data record.
 * <p>
 * It is used as value item in a treemap while doing cDNA splice site analysis.
 * It contains matching boundaries (either start or end positions) of genemodels and cDNAs in order to calculate a cDNA splice site score later on by comparing the genemodel boundary to the cDNA boundary splice site matches.
 * 
 * @author Sebastian R. Spiegler
 * @see 
 *     uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis.CDnaSpliceSiteAnalysis
 * @see 
 *     uk.ac.sanger.psu.gfmerge.analysis.simfeature_analysis.tools.CDnaSpliceSiteAnalysisTools
 * @version 1.0
 */
public class RecordGmCDna
{
  /** splice site of a genemodel exon (either start or end position)
   */
  public Integer gmBoundary;
  /** splice site of a cDNA feature (either start or end position)
   */
  public ArrayList cDnaBoundaries;

  /** constructor of RecordGmCDna objects.
   * <p>
   * After initialzation the genemodel boundary attribute is null and the cDNA boundary ArrayList is empty.
   */
  public RecordGmCDna()
  {
    gmBoundary     = null;
    cDnaBoundaries = new ArrayList();
  }

}
