/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.datacomp;

import java.util.*;
import org.biojava.bio.seq.*;
import org.biojava.bio.symbol.*;

import uk.ac.sanger.psu.gfmerge.util.biotools.*;
import uk.ac.sanger.psu.gfmerge.datacomp.*;

/** class is representing a similarity feature used as evidence for correct predictions. 
 * <p>
 * This class wraps the BioJava Feature class and contains feature hits. Those hits are either a Blast or a cDNA feature.
 * For example:
 * <pre>
 * SimFeature simFeature = new SimFeature(feature);
 * </pre>
 * 
 * @author Sebastian R. Spiegler
 * @see uk.ac.sanger.psu.gfmerge.datacomp.GeneModel
 * @see uk.ac.sanger.psu.gfmerge.datacomp.LocateAble
 * @version 1.0
 */

public class SimFeature extends GFMergeFeature{

  ///////////////////////////////////////
  // attributes



  ///////////////////////////////////////
  // constructor

  /** constructor for SimFeature objects
   * 
   * @param feature BioJava feature object
   */
  public SimFeature(StrandedFeature feature)
  {
    super(feature);
  }
} // end
