/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.util.algotools;

import java.util.*;

/** class MyTreeMap adds some more functionality to TreeMap
 * 
 * @version 1.0
 */
public class MyTreeMap extends TreeMap implements SortedMap
{
  /** stores maximum length [long] seen during processing.
   * Public set method!
   */
  private long maxObjectFound;

  /** constructor of MyTreeMap objects
   */
  public MyTreeMap()
  {
    super();
  }

 /** accessor method which returns max length seen.
  * 
  * @return max length seen
  */
 public long getMaxObjectFound()
 {
   return maxObjectFound;
 }

 /** accessor method which sets max length seen.
  * Public set-method!
  * 
  * @param _maxObjectFound max length seen
  */
 public void setMaxObjectFound(long _maxObjectFound)
 {
   maxObjectFound = _maxObjectFound;
 }

 /** method which returns the successor of a key.
  * Returns null if last key is passed as argument.
  * 
  * @param key key for which successor is sought
  * @return successor of a key
  */
 public Object nextKey(Object key)
 {
   if (key != this.lastKey()) // if not last key return next key
   {
     SortedMap sMap = new TreeMap(this.tailMap(key));
     sMap.remove(key);
     return sMap.firstKey();
   }
   else                      // if last key return null
   {
     return null;
   }
 }

 /** method which returns the predecessor of a key.
  * Returns null if first key is passed as argument.
  * 
  * @param key key for which predecessor is sought
  * @return predecessor of a key
  */
 public Object previousKey(Object key)
 {
   if (key != this.firstKey())  // if not first key return previous key
   {
     SortedMap sMap = new TreeMap(this.headMap(key));
     sMap.remove(key);
     return sMap.lastKey();
   }
   else                        // if first key return null
   {
     return null;
   }
 }
}
