/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.util.io;

import org.biojava.bio.*;
import org.biojava.bio.seq.*;
import org.biojava.bio.seq.io.*;
import java.io.*;
import java.util.*;

/** class which reads EMBL files into objects using SeqIOTools.readEmbl().
 */
public class GFMergeInput
{
  /** method which returns a BioJava SequenceIterator.
   *
   * @param fname filename of EMBL file
   * @return BioJava SequenceIterator
   */
  public static SequenceIterator getSeq (String fname)
  {
    BufferedReader br = null;

    try {

      //create a buffered reader to read the sequence file
      br = new BufferedReader(new FileReader(fname));

    }
    catch (FileNotFoundException ex) {
      //can't find the file specified by fname
      ex.printStackTrace();
      System.exit(-1);
    }

    //read the EMBL File
    SequenceIterator sequences = SeqIOTools.readEmbl(br);

    return sequences;
  }
}
