/*
 * This file is part of GFMerge. Copyright (c) 2007 Genome
 * Research Limited.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published 
 * by  the Free Software Foundation; either version 2 of the License or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.LIB.  If not, write to 
 * the Free Software Foundation Inc., 59 Temple Place - Suite 330, 
 * Boston, MA  02111-1307 USA
 */

package uk.ac.sanger.psu.gfmerge.util.io;

import java.util.*;
import java.io.*;

import org.biojava.bio.seq.*;
import org.biojava.bio.seq.io.*;

import uk.ac.sanger.psu.gfmerge.datacomp.*;
import uk.ac.sanger.psu.gfmerge.analysis.tools.*;
import uk.ac.sanger.psu.gfmerge.util.io.*;
import uk.ac.sanger.psu.gfmerge.util.biotools.*;

/** class which writes EMBL files using BioJava SeqIOTools.writeEmbl().
 * 
 * @author Sebastian R. Spiegler
 * @version 1.0
 */
public class GFMergeOutput {

////////////////////////////////////////////////////////////////////////
// save picked features to file
//
  /** method which saves picked features to a file.
   * 
   * @param filename output filename
   * @param arrListOfFeatRegions ArrayList of genemodel regions
   * @param prediction Prediction object from which sequence is retrieved
   */
  public static void saveFeat2File(String filename,
                                   ArrayList arrListOfFeatRegions,
                                   Prediction prediction) {
    Sequence predSeq = prediction.getSequence();
    Sequence newSeq =
        BioTools.createNewSeqOfPickedGms(predSeq, arrListOfFeatRegions);

    // save new sequence object in file
    GFMergeOutput.writeSeq2File(filename, newSeq);
  }

////////////////////////////////////////////////////////////////////////
// save removed features to file
//
  /** method which saves removed features to a file.
   * 
   * @param filename output filename
   * @param arrListOfFeatRegions_before ArrayList of genemodel regions 
   *     before processing
   * @param arrListOfFeatRegions_after ArrayList of genemodel regions 
   *     after processing
   * @param prediction Prediction object from which sequence is retrieved
   */
  public static void saveRemovedFeat2File(String filename,
                                          ArrayList arrListOfFeatRegions_before,
                                          ArrayList arrListOfFeatRegions_after,
                                          Prediction prediction) {
    ArrayList removedGmRegionArr =
        SavScoreInBioFeat.getRemovedFeatures(arrListOfFeatRegions_before,
                                             arrListOfFeatRegions_after);

    GFMergeOutput.saveFeat2File(filename,
                                removedGmRegionArr,
                                prediction);
  }

////////////////////////////////////////////////////////////////////////
// write sequence object to file
//

  /** method which writes BioJava sequence to a file.
   * 
   * @param filename output filename
   * @param seq BioJava sequence
   */
  private static void writeSeq2File(String filename, Sequence seq) {
    try {
      File outputFile = new File(filename);

      //FileOutputStream
      FileOutputStream fos = new FileOutputStream(outputFile);

      SeqIOTools.writeEmbl(fos, seq);
      fos.close();
    } // try

    catch (IOException ioe) {
      System.out.print("IO Error in ");
      System.out.println(ioe.getMessage());
    } // catch IOException*/
  }

}
